==> v1.1.6.zip: siyuan/README.md <==
<p align="center">
<img alt="SiYuan" src="https://b3log.org/images/brand/siyuan-128.png">
<br>
<em>The next generation PKM system, your digital garden</em>
<br><br>
<a title="Releases" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/release/siyuan-note/siyuan.svg?style=flat-square&color=FF9900"></a>
<a title="Downloads" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/downloads/siyuan-note/siyuan/total.svg?style=flat-square&color=blueviolet"></a>
<a title="Docker Pulls" target="_blank" href="https://hub.docker.com/r/b3log/siyuan"><img src="https://img.shields.io/docker/pulls/b3log/siyuan.svg?logo=docker&style=flat-square&color=99CCFF"></a>
<a title="Discord" target="_blank" href="https://discord.gg/bzfCBwMzdP"><img src="https://img.shields.io/discord/808152298789666826?label=discord&logo=discord&style=flat-square&color=orange"></a>
<a title="Hits" target="_blank" href="https://github.com/siyuan-note/siyuan"><img src="https://hits.b3log.org/siyuan-note/siyuan.svg"></a>
</p>

<p align="center">
<a href="https://github.com/siyuan-note/siyuan/blob/master/README_zh_CN.md">中文</a>
</p>

## 💡 Introduction

SiYuan is a local-first personal knowledge management system, support fine-grained block-level reference and Markdown instant-render editing.

![bg1.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@762fc276da1f713551b61799f04a3661ccd17369/screenshots/bg1.png)

![bg3.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@762fc276da1f713551b61799f04a3661ccd17369/screenshots/bg3.png)

## ✨  Features

* Content block
  * Block-level reference and two-way links
  * Document relationship diagram, global relationship diagram
  * Bookmark collection
  * Dynamic query embed
  * URL for browser visit or link with other software
* Markdown
  * Instant Rendering editing mode similar to Typora
  * Support mathematical formulas, charts, flowcharts, Gantt charts, timing charts, staffs, etc.
  * Paste HTML automatically converted to Markdown
  * Configure Markdown to analyze detailed rendering parameters  
* MinMap mode
  * Support zoom, drag, layout and theme, etc.
  * Keep editing and Markdown in sync
* Use on the browser, support mobile-end
* Hierarchical tag
* Multi-window, multi-tab, drag and drop to split screen
* WebDAV
* Fulltext search
* Themes and icons
  * Built-in bright and dark themes
  * Built-in two sets of icons, Material and Ant Design
  * Support custom themes and icons
* Export
  * Standard Markdown and TextBundle export
  * Content block reference provides anchor text + embedded blockquote option
  * Copy to WeChat MP, Zhihu and Yuque
* Versioning and Sync
  * [Online Workspace](https://ld246.com/xanadu/)
  * [Online Publishing](https://ld246.com/udanax/)

## 🗺️ Roadmap

* [SiYuan development plan and progress](https://github.com/siyuan-note/siyuan/projects)
* [SiYuan Change logs](https://github.com/siyuan-note/siyuan/blob/master/CHANGE_LOGS.md)

## 🛠️ Download Setup

* [B3log](https://b3log.org/siyuan/en/download.html)
* [GitHub](https://github.com/siyuan-note/siyuan/releases)
* [Docker](https://hub.docker.com/r/b3log/siyuan)

To get the latest Insider Preview, please send an email with your GitHub login name to 845765@qq.com, and we will invite you to join the SiYuan Insider Preview team, thanks.

## 📜 Documentation

* [User Guide](https://ld246.com/udanax/1602224134353)
* [SiYuan - A desktop Markdown Block-Reference and Bidirectional-Link note-taking application](https://ld246.com/article/1598872180233)
* [Markdown implements the exploration of block-level reference bidirectional links](https://ld246.com/article/1597226949061)

## 🏘️ Community

* [Discord](https://discord.gg/bzfCBwMzdP)

## 💌 Participate in contribution

At present, some components of SiYuan are open source, and contributions are welcome.

* [User Guide](https://github.com/siyuan-note/user-guide-en_US)
* [Appearance and language](https://github.com/siyuan-note/appearance)
* [Markdown Engine](https://github.com/88250/lute)

## 🙏 Acknowledgement

SiYuan is made possible by the [Vditor](https://github.com/Vanessa219/vditor) and [Lute](https://github.com/88250/lute) open source project and other open source software.

<details>
<summary>Kernel</summary>

* [https://github.com/golang/go](https://github.com/golang/go) `BSD-3-Clause License`
* [https://github.com/vanng822/css](https://github.com/vanng822/css) `MIT License`
* [https://github.com/studio-b12/gowebdav](https://github.com/studio-b12/gowebdav) `BSD-3-Clause License`
* [https://github.com/88250/gulu](https://github.com/88250/gulu) `Mulan PSL v2`
* [https://github.com/olahol/melody](https://github.com/olahol/melody) `BSD-2-Clause License`
* [https://github.com/Masterminds/sprig](https://github.com/Masterminds/sprig) `MIT License`
* [https://github.com/Xuanwo/go-locale](https://github.com/Xuanwo/go-locale) `Apache-2.0 License`
* [https://github.com/blastrain/vitess-sqlparser](https://github.com/blastrain/vitess-sqlparser) `Apache-2.0 License`
* [https://github.com/common-nighthawk/go-figure](https://github.com/common-nighthawk/go-figure) `MIT License`
* [https://github.com/dustin/go-humanize](https://github.com/dustin/go-humanize) `MIT License`
* [https://github.com/emirpasic/gods](https://github.com/emirpasic/gods) `BSD-2-Clause License`
* [https://github.com/facette/natsort](https://github.com/facette/natsort) `BSD-3-Clause License`
* [https://github.com/fsnotify/fsnotify](https://github.com/fsnotify/fsnotify) `BSD-3-Clause License`
* [https://github.com/gin-contrib/cors](https://github.com/gin-contrib/cors) `MIT License`
* [https://github.com/gin-gonic/gin](https://github.com/gin-gonic/gin) `MIT License`
* [https://github.com/go-git/go-git](https://github.com/go-git/go-git) `Apache-2.0 License`
* [https://github.com/jackpal/gateway](https://github.com/jackpal/gateway) `BSD-3-Clause License`
* [https://github.com/mitchellh/go-ps](https://github.com/mitchellh/go-ps) `MIT License`
* [https://github.com/mssola/user_agent](https://github.com/mssola/user_agent) `MIT License`
* [https://github.com/panjf2000/ants](https://github.com/panjf2000/ants) `MIT License`
* [https://github.com/parnurzeal/gorequest](https://github.com/parnurzeal/gorequest) `MIT License`
* [https://github.com/golang/crypto](https://github.com/golang/crypto) `BSD-3-Clause License`
* [https://github.com/golang/net](https://github.com/golang/net) `BSD-3-Clause License`
* [https://github.com/golang/text](https://github.com/golang/text) `BSD-3-Clause License`
* [https://github.com/go-gorm/sqlite](https://github.com/go-gorm/sqlite) `MIT License`
* [https://github.com/go-gorm/gorm](https://github.com/go-gorm/gorm) `MIT License`
</details>

<details>
<summary>UI</summary>

* [https://github.com/microsoft/TypeScript](https://github.com/microsoft/TypeScript) `Apache-2.0 License`
* [https://github.com/electron/electron](https://github.com/electron/electron) `MIT License`
* [https://github.com/d3/d3](https://github.com/d3/d3) `BSD-3-Clause License`
* [https://github.com/google/diff-match-patch](https://github.com/google/diff-match-patch) `Apache-2.0 License`
* [https://github.com/rtfpessoa/diff2html](https://github.com/rtfpessoa/diff2html) `MIT License`
* [https://github.com/mozilla/pdfjs-dist](https://github.com/mozilla/pdfjs-dist) `Apache-2.0 License`
* [https://github.com/blueimp/JavaScript-MD5](https://github.com/blueimp/JavaScript-MD5) `MIT License`
* [https://github.com/fex-team/kityminder-core](https://github.com/fex-team/kityminder-core) `BSD-3-Clause License`
* [https://github.com/codemirror/CodeMirror](https://github.com/codemirror/CodeMirror) `MIT License`
* [https://github.com/hakimel/reveal.js](https://github.com/hakimel/reveal.js) `MIT License`
</details>

==> v1.2.0.zip: siyuan/README.md <==
<p align="center">
<img alt="SiYuan" src="https://b3log.org/images/brand/siyuan-128.png">
<br>
<em>The next generation PKM system, your digital garden</em>
<br><br>
<a title="Releases" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/release/siyuan-note/siyuan.svg?style=flat-square&color=FF9900"></a>
<a title="Downloads" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/downloads/siyuan-note/siyuan/total.svg?style=flat-square&color=blueviolet"></a>
<a title="Docker Pulls" target="_blank" href="https://hub.docker.com/r/b3log/siyuan"><img src="https://img.shields.io/docker/pulls/b3log/siyuan.svg?logo=docker&style=flat-square&color=99CCFF"></a>
<a title="Discord" target="_blank" href="https://discord.gg/bzfCBwMzdP"><img src="https://img.shields.io/discord/808152298789666826?label=discord&logo=discord&style=flat-square&color=orange"></a>
<a title="Hits" target="_blank" href="https://github.com/siyuan-note/siyuan"><img src="https://hits.b3log.org/siyuan-note/siyuan.svg"></a>
</p>

<p align="center">
<a href="https://github.com/siyuan-note/siyuan/blob/master/README_zh_CN.md">中文</a>
</p>

## 💡 Introduction

SiYuan is a local-first personal knowledge management system, support fine-grained block-level reference and Markdown WYSIWYG.

![feature0.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@8489397401cf5025eab847dfb26a4f3896be5363/screenshots/feature0.png)

![feature1-1.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@8489397401cf5025eab847dfb26a4f3896be5363/screenshots/feature1-1.png)

## ✨  Features

* Content block
  * Block-level reference and two-way links
  * Document relationship diagram, global relationship diagram
  * Custom attributes
  * SQL query embed
  * Protocol `siyuan://`
* Editor
  * Block-style
  * Markdown WYSIWYG
  * List outline
  * Block zoom-in
  * Block horizontal layout
  * Million-word large document editing
  * Mathematical formulas, charts, flowcharts, Gantt charts, timing charts, staffs, etc.
  * Web clipping
* Export
  * Standard Markdown with assets
  * Content block reference provides anchor text + embedded blockquote option
  * Copy to WeChat MP, Zhihu and Yuque
* Hierarchical tag
* Multi-tab, drag and drop to split screen
* Fulltext search
* Template snippet
* Keymap
* Themes and icons
* Data cloud backup, end-to-end encryption
* Android APP
* Docker deployment

## 🗺️ Roadmap

* [SiYuan development plan and progress](https://github.com/siyuan-note/siyuan/projects)
* [SiYuan Change logs](https://github.com/siyuan-note/siyuan/blob/master/CHANGE_LOGS.md)

## 🛠️ Download Setup

* [B3log](https://b3log.org/siyuan/en/download.html)
* [GitHub](https://github.com/siyuan-note/siyuan/releases)
* [Docker](https://hub.docker.com/r/b3log/siyuan)

To get the latest Insider Preview, please send an email with your GitHub login name to 845765@qq.com, and we will invite you to join the SiYuan Insider Preview team, thanks.

## 📜 Documentation

* [SiYuan - A desktop Markdown Block-Reference and Bidirectional-Link note-taking application](https://ld246.com/article/1598872180233)
* [Markdown implements the exploration of block-level reference bidirectional links](https://ld246.com/article/1597226949061)

## 🏘️ Community

* [Discord](https://discord.gg/bzfCBwMzdP)

## 💌 Participate in contribution

At present, some components of SiYuan are open source, and contributions are welcome.

* [User Guide](https://github.com/siyuan-note/user-guide-en_US)
* [Appearance](https://github.com/siyuan-note/appearance)
* [Markdown Engine](https://github.com/88250/lute)
* [Chrome Extension](https://github.com/siyuan-note/siyuan-chrome)

## 🙏 Acknowledgement

SiYuan is made possible by the [Vditor](https://github.com/Vanessa219/vditor) and [Lute](https://github.com/88250/lute) open source project and other open source software.

* [https://github.com/golang/go](https://github.com/golang/go) `BSD-3-Clause License`
* [https://github.com/vanng822/css](https://github.com/vanng822/css) `MIT License`
* [https://github.com/88250/gulu](https://github.com/88250/gulu) `Mulan PSL v2`
* [https://github.com/olahol/melody](https://github.com/olahol/melody) `BSD-2-Clause License`
* [https://github.com/Masterminds/sprig](https://github.com/Masterminds/sprig) `MIT License`
* [https://github.com/Xuanwo/go-locale](https://github.com/Xuanwo/go-locale) `Apache-2.0 License`
* [https://github.com/blastrain/vitess-sqlparser](https://github.com/blastrain/vitess-sqlparser) `Apache-2.0 License`
* [https://github.com/common-nighthawk/go-figure](https://github.com/common-nighthawk/go-figure) `MIT License`
* [https://github.com/dustin/go-humanize](https://github.com/dustin/go-humanize) `MIT License`
* [https://github.com/emirpasic/gods](https://github.com/emirpasic/gods) `BSD-2-Clause License`
* [https://github.com/facette/natsort](https://github.com/facette/natsort) `BSD-3-Clause License`
* [https://github.com/fsnotify/fsnotify](https://github.com/fsnotify/fsnotify) `BSD-3-Clause License`
* [https://github.com/gin-gonic/gin](https://github.com/gin-gonic/gin) `MIT License`
* [https://github.com/jackpal/gateway](https://github.com/jackpal/gateway) `BSD-3-Clause License`
* [https://github.com/mitchellh/go-ps](https://github.com/mitchellh/go-ps) `MIT License`
* [https://github.com/mssola/user_agent](https://github.com/mssola/user_agent) `MIT License`
* [https://github.com/panjf2000/ants](https://github.com/panjf2000/ants) `MIT License`
* [https://github.com/parnurzeal/gorequest](https://github.com/parnurzeal/gorequest) `MIT License`
* [https://github.com/microsoft/TypeScript](https://github.com/microsoft/TypeScript) `Apache-2.0 License`
* [https://github.com/electron/electron](https://github.com/electron/electron) `MIT License`
* [https://github.com/visjs/vis-network](https://github.com/visjs/vis-network) `Apache-2.0 License`
* [https://github.com/google/diff-match-patch](https://github.com/google/diff-match-patch) `Apache-2.0 License`
* [https://github.com/rtfpessoa/diff2html](https://github.com/rtfpessoa/diff2html) `MIT License`
* [https://github.com/mozilla/pdfjs-dist](https://github.com/mozilla/pdfjs-dist) `Apache-2.0 License`
* [https://github.com/blueimp/JavaScript-MD5](https://github.com/blueimp/JavaScript-MD5) `MIT License`
* [https://github.com/fex-team/kityminder-core](https://github.com/fex-team/kityminder-core) `BSD-3-Clause License`
* [https://github.com/hakimel/reveal.js](https://github.com/hakimel/reveal.js) `MIT License`
